from confduino.proginstall import install_programmer
from confduino.util import AutoBunch
from entrypoint2 import entrypoint


@entrypoint
def install(replace_existing=False):
    """install stk200 programmer."""
    bunch = AutoBunch()
    bunch.name = 'STK200'
    bunch.protocol = 'stk200'
    # bunch.force = 'true'
    # bunch.delay=200

    install_programmer('stk200', bunch, replace_existing=replace_existing)
